@@ -1075,14 +1075,17 @@ void cw::send_ch(int ch)
 	float tc = 1200.0 / progdefaults.CWspeed;
 	float ta = 0.0;
 	float tch = 3 * tc, twd = 4 * tc;
+	int   stdwpm = progdefaults.CWspeed;
 
-	if (progdefaults.CWusefarnsworth && (progdefaults.CWspeed > progdefaults.CWfarnsworth)) {
+	if (progdefaults.CWusefarnsworth && (stdwpm > progdefaults.CWfarnsworth)) {
 		ta = 60000.0 / progdefaults.CWfarnsworth - 37200.0 / progdefaults.CWspeed;
 		tch = 3 * ta / 19;
 		twd = 4 * ta / 19;
+		stdwpm = progdefaults.CWfarnsworth;
+	}
+	if (progdefaults.CWusewordsworth && (stdwpm > progdefaults.CWwordsworth)) {
+		twd += (50.0 * 1200.0 / progdefaults.CWwordsworth - 50.0 * 1200.0 / stdwpm);
 	}
-	if (progdefaults.CWusewordsworth && (progdefaults.CWspeed > progdefaults.CWwordsworth))
-		twd = 4800 / progdefaults.CWwordsworth;
 
 	tc *= kfactor;
 	tch *= kfactor;
@@ -1101,17 +1104,16 @@ void cw::send_ch(int ch)
 		kpost = progdefaults.CWpost * kfactor;
 
 	if ((ch == ' ') || (ch == '\n')) {
-		send_symbol(0, 
-			twd,
-			SPACE);
+		while (twd > 0) {
+			send_symbol(0, (twd < 4096 ? twd : 4096), SPACE);
+			twd -= 4096;
+		}
 		put_echo_char(progdefaults.rx_lowercase ? tolower(ch) : ch);
 		return;
 	}
 
 	code = morse->tx_lookup(ch);
 
-//std::cout << (char)ch << "[" << code << "]"; std::cout.flush();
-
 	if (!code.length()) {
 		return;
 	}
@@ -1249,10 +1251,9 @@ int cw::tx_process()
 		progdefaults.CW_KEYLINE_on_cat_port ||
 		progdefaults.CW_KEYLINE_on_ptt_port)
 		send_CW(c);
-//	else {
 	send_ch(c);
 	first_char = false;
-//	}
+
 	char_samples = acc_symbols;
 
 	return 0;
@@ -1390,10 +1391,11 @@ void flrig_cwio_send(char c)
 	if (c == ' ') {
 		if (lastcwiochar == ' ') {
 			tc *= 7;
-			if (progdefaults.CWusewordsworth && (progdefaults.CWspeed > progdefaults.CWwordsworth))
-				tc *= 1.0 * progdefaults.CWspeed / progdefaults.CWwordsworth;
-			if (progdefaults.CWusewordsworth && (progdefaults.CWspeed > progdefaults.CWwordsworth))
-				tc = 4800 / progdefaults.CWwordsworth;
+			if (progdefaults.CWusewordsworth && 
+				((progdefaults.CWusefarnsworth ? progdefaults.CWfarnsworth : progdefaults.CWspeed) 
+				  > progdefaults.CWwordsworth) )
+				tc += (50.0 * 1200 / progdefaults.CWwordsworth - 50.0 * 1200 / 
+				(progdefaults.CWusefarnsworth ? progdefaults.CWfarnsworth : progdefaults.CWspeed) );
 		}
 		else
 		tc *= 5;
@@ -1563,20 +1565,17 @@ void send_cwio(int c)
 	if (tc <= 0) tc = 1;
 	float ta = 0.0;
 	float tch = 3 * tc, twd = 4 * tc;
+	int   stdwpm = progdefaults.CWspeed;
 
-//	Cserial *ser = &CW_KEYLINE_serial;
-//	if (progdefaults.CW_KEYLINE_on_cat_port)
-//		ser = &rigio;
-//	else if (progdefaults.CW_KEYLINE_on_ptt_port)
-//		ser = &push2talk->serPort;
-
-	if (progdefaults.CWusefarnsworth && (progdefaults.CWspeed > progdefaults.CWfarnsworth)) {
-		ta = 60000.0 / progdefaults.CWfarnsworth - 37200 / progdefaults.CWspeed;
+	if (progdefaults.CWusefarnsworth && (stdwpm > progdefaults.CWfarnsworth)) {
+		ta = 60000.0 / progdefaults.CWfarnsworth - 37200.0 / progdefaults.CWspeed;
 		tch = 3 * ta / 19;
 		twd = 4 * ta / 19;
+		stdwpm = progdefaults.CWfarnsworth;
+	}
+	if (progdefaults.CWusewordsworth && (stdwpm > progdefaults.CWwordsworth)) {
+		twd += (50.0 * 1200.0 / progdefaults.CWwordsworth - 50.0 * 1200.0 / stdwpm);
 	}
-	if (progdefaults.CWusewordsworth && (progdefaults.CWspeed > progdefaults.CWwordsworth))
-		twd = 4800 / progdefaults.CWwordsworth;
 
 	if (c == 0x0a) c = ' ';
 
