@@ -80,7 +80,7 @@ const struct mode_info_t mode_info[NUM_MODES] = {
 {MODE_CONTESTIA_64_1000,&contestia_64_1000_modem,"Cont-64/1K","Cont64-1K","","CONTESTI64/1000","CONTESTI","","CT64/1K",DISABLED_IO},
 {MODE_CONTESTIA_64_2000,&contestia_64_2000_modem,"Cont-64/2K","Cont64-2K","","CONTESTI64/2000","CONTESTI","","CT64/2K",DISABLED_IO},
 
-{MODE_DOMINOEXMICRO,&dominoexmicro_modem,"DOMEX Micro","DominoEX Micro","DOMINOEXMICRO","DOMINO","DOMINO","","DM M", DISABLED_IO },
+{MODE_DOMINOEXMICRO,&dominoexmicro_modem,"DOMEXM","DominoEX Micro","DOMINOEXMICRO","DOMINO","DOMINO","","DM M", DISABLED_IO },
 {MODE_DOMINOEX4,&dominoex4_modem,"DOMEX4","DominoEX 4","DOMINOEX4","DOMINO","DOMINO","","DM 4", DISABLED_IO },
 {MODE_DOMINOEX5,&dominoex5_modem,"DOMEX5","DominoEX 5","DOMINOEX5","DOMINO","DOMINO","","DM 5", DISABLED_IO },
 {MODE_DOMINOEX8,&dominoex8_modem,"DOMEX8","DominoEX 8","DOMINOEX8","DOMINO","DOMINO","","DM 8", DISABLED_IO },
@@ -90,13 +90,13 @@ const struct mode_info_t mode_info[NUM_MODES] = {
 {MODE_DOMINOEX44,&dominoex44_modem,"DOMX44","DominoEX 44","DOMINOEX44","DOMINO","DOMINO","","DM44", ARQ_IO | KISS_IO },
 {MODE_DOMINOEX88,&dominoex88_modem,"DOMX88","DominoEX 88","DOMINOEX88","DOMINO","DOMINO","","DM88", ARQ_IO | KISS_IO },
 
-{MODE_FELDHELL,&feld_modem,"FELDHELL","Feld Hell","","HELL","HELL","","HELL", DISABLED_IO },
-{MODE_SLOWHELL,&feld_slowmodem,"SLOWHELL","Slow Hell","","HELL","HELL","","SHLL", DISABLED_IO },
-{MODE_HELLX5,&feld_x5modem,"HELLX5","Feld Hell X5","","HELL","HELL","","HLX5", DISABLED_IO },
-{MODE_HELLX9,&feld_x9modem,"HELLX9","Feld Hell X9","","HELL","HELL","","HLX9", DISABLED_IO },
-{MODE_FSKH245,&feld_FMmodem,"FSKH245","FSK Hell-245","","FSKH245","HELL","FSKH245","FSKHL", DISABLED_IO  },
-{MODE_FSKH105,&feld_FM105modem,"FSKH105","FSK Hell-105","","FSKH105","HELL","FSKH105","H105", DISABLED_IO },
-{MODE_HELL80,&feld_80modem,"HELL80","Hell 80","","HELL80","HELL","HELL80","HL80", DISABLED_IO },
+{MODE_FELDHELL, &feld_modem,     "FELDHELL", "Feld Hell",    "", "HELL", "HELL", "",         "HELL",  DISABLED_IO },
+{MODE_SLOWHELL, &feld_slowmodem, "SLOWHELL", "Slow Hell",    "", "HELL", "HELL", "SLOWHELL", "SHLL",  DISABLED_IO },
+{MODE_HELLX5,   &feld_x5modem,   "HELLX5",   "Feld Hell X5", "", "HELL", "HELL", "HELLX5 ",  "HLX5",  DISABLED_IO },
+{MODE_HELLX9,   &feld_x9modem,   "HELLX9",   "Feld Hell X9", "", "HELL", "HELL", "HELLX9",   "HLX9",  DISABLED_IO },
+{MODE_FSKH245,  &feld_FMmodem,   "FSKH245",  "FSK Hell-245", "", "HELL", "HELL", "FSKH245",  "FSKHL", DISABLED_IO },
+{MODE_FSKH105,  &feld_FM105modem,"FSKH105",  "FSK Hell-105", "", "HELL", "HELL", "FSKH105",  "H105",  DISABLED_IO },
+{MODE_HELL80,   &feld_80modem,   "HELL80",   "Hell 80",      "", "HELL", "HELL", "HELL80",   "HL80",  DISABLED_IO },
 
 {MODE_MFSK8,&mfsk8_modem,"MFSK8","MFSK-8","MFSK8","MFSK8","MFSK","MFSK8","MK 8", DISABLED_IO  },
 {MODE_MFSK16,&mfsk16_modem,"MFSK16","MFSK-16","MFSK16","MFSK16","MFSK","MFSK16","MK16", ARQ_IO | KISS_IO },
@@ -190,7 +190,7 @@ const struct mode_info_t mode_info[NUM_MODES] = {
 
 {MODE_RTTY,&rtty_modem,"RTTY","RTTY","RTTY","RTTY","RTTY","","RY", DISABLED_IO },
 
-{MODE_THORMICRO,&thormicro_modem,"THOR Micro","THOR Micro","THORM","THOR-M","THOR","","THM", DISABLED_IO  },
+{MODE_THORMICRO,&thormicro_modem,"THORM","THOR Micro","THORM","THOR-M","THOR","","THM", DISABLED_IO  },
 {MODE_THOR4,&thor4_modem,"THOR4","THOR 4","THOR4","THOR4","THOR","","TH4", DISABLED_IO  },
 {MODE_THOR5,&thor5_modem,"THOR5","THOR 5","THOR5","THOR5","THOR","","TH5", DISABLED_IO  },
 {MODE_THOR8,&thor8_modem,"THOR8","THOR 8","THOR8","THOR8","THOR","","TH8", DISABLED_IO  },
