@@ -1,5 +1,5 @@
 // tux avatar
-unsigned char tux_img[] = {
+unsigned char tux_img[59*74*3] = {
  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156,  156, 
