@@ -163,8 +163,8 @@ enum {
 	
 	MODE_OFDM_500F,
 	MODE_OFDM_750F,
-	MODE_OFDM_2000F,
-	MODE_OFDM_2000,
+//	MODE_OFDM_2000F,
+//	MODE_OFDM_2000,
 	MODE_OFDM_3500,
 	
 	MODE_OLIVIA,
