@@ -140,4 +140,20 @@ extern void writeLog(std::string fname, cQsoDb *db);
 
 extern const char* log_power();
 
+//======================================================================
+// eQSL
+extern void submit_eQSL(cQsoRec &rec, std::string msg);
+//======================================================================
+
+//======================================================================
+// Cloudlog
+extern void submit_cloudlog(cQsoRec &rec);
+//======================================================================
+
+//======================================================================
+// UDP log
+extern void post_udp_log(cQsoRec &rec);
+extern void udp_test();
+//======================================================================
+
 #endif
