@@ -36,7 +36,7 @@ public:
 	void	init();
 	void	rx_init();
 	void	restart();
-	void	tx_init(SoundBase *sc);
+	void	tx_init();
 	int		rx_process(const double *buf, int len);
 	int		tx_process();
 
