@@ -173,7 +173,7 @@ public:
 	~view_rtty();
 	void init();
 	void rx_init();
-	void tx_init(SoundBase *sc){}
+	void tx_init() {}
 	void restart();
 	void reset_filters(int ch);
 	int rx_process(const double *buf, int len);
