@@ -33,6 +33,8 @@
 #include <sys/stat.h>
 #include <cstdlib>
 #include <string>
+#include <time.h>
+#include <sys/time.h>
 
 #include <FL/fl_utf8.h>
 
@@ -488,6 +490,38 @@ void MilliSleep(long msecs)
 }
 #endif
 
+// return current tick time in seconds
+double fsk_now()
+{
+	static struct timeval t1;
+	gettimeofday(&t1, NULL);
+	return t1.tv_sec + t1.tv_usec / 1e6;
+}
+
+// sub millisecond accurate sleep function
+// sleep_time in seconds
+// NOT THREAD SAFE !!!
+int accu_sleep (double sleep_time)
+{
+	struct timespec tv;
+	double end_at = fsk_now() + sleep_time;
+	double delay = sleep_time - 0.1e-3;
+	tv.tv_sec = (time_t) delay;
+	tv.tv_nsec = (long) ((delay - tv.tv_sec) * 1e+9);
+	int rval = 0;
+	while (1) {
+		rval = nanosleep (&tv, &tv);
+		if (rval == 0)
+			break;
+		else if (errno == EINTR)
+			continue;
+		else 
+			return rval;
+	}
+	while (fsk_now() < end_at);
+	return 0;
+}
+
 /** ********************************************************************
  * Returns 0 if a process is running, 0 if not there and -1 if the
  * test cannot be made.
