@@ -70,6 +70,7 @@
 
 #include "lgbook.h"
 #include "logsupport.h"
+#include "logger.h"
 #include "qso_db.h"
 #include "dx_dialog.h"
 #include "contest.h"
@@ -80,6 +81,8 @@
 
 #include "spectrum_viewer.h"
 
+#include "ui_colors.h"
+
 #define STATUS_FILENAME "status"
 
 status progStatus = {
@@ -762,6 +765,8 @@ if (!bWF_only) {
 //----------------------------------------------------------------------
 	spref.set("vumeter_shown", vumeter_shown);
 
+	ui_colors.save("fldigi_UI_colors");
+
 	modeband.save_mode_state();
 }
 
@@ -837,19 +842,13 @@ void status::loadLastState()
 	noCATwidth = strbuff;
 
 	spref.get("main_x", mainX, mainX);
-	if (mainX > Fl::w())
-		mainX = 0;
-
 	spref.get("main_y", mainY, mainY);
-	if (mainY > Fl::h())
-		mainY = 0;
 
 	spref.get("main_w", mainW, mainW);
 	if (mainW < WMIN) mainW = WMIN;
 	if (mainW > Fl::w()) mainW = Fl::w();
 
 	spref.get("main_h", mainH, mainH);
-//	if (mainH < HMIN) mainH = HMIN;
 	if (mainH > Fl::w()) mainH = Fl::h();
 
 	spref.get("wf_ui", i, WF_UI); WF_UI = i;
@@ -1122,6 +1121,11 @@ void status::loadLastState()
 
 	modeband.load_mode_state();
 
+	load_udp_prefs();
+	load_cloud_prefs();
+
+	ui_colors.load("fldigi_UI_colors");
+
 	set_debug_mask(debug_mask);
 }
 
