@@ -20,6 +20,8 @@
 // ----------------------------------------------------------------------------
 
 #include <config.h>
+
+#include <iostream>
 #include <cmath>
 
 #include <FL/Fl.H>
@@ -35,7 +37,11 @@ void PWRmeter::draw()
 {
 	if (select_ == 4) select_auto();
 
-	sval = round(meter_width * (value_) / (maximum_));
+	if (0)
+		sval = round(meter_width * value_ / maximum_);
+	else
+		sval = round(meter_width * peak_ / maximum_);
+
 	if (sval > meter_width) sval = meter_width;
 	if (sval < 0) sval = 0;
 
@@ -148,6 +154,9 @@ PWRmeter::PWRmeter(int X, int Y, int W, int H, const char* l)
 
 	maximum_ = 100.0;
 	value_ = 0.0;
+	peak_ = 0.0;
+	ppeak = 0;
+	for (int n = 0; n < NPEAKS; n++) peaks_[n] = 0.0;
 
 	select_ = 2; // 100 W scale
 
