@@ -1,34 +1,31 @@
 // ----------------------------------------------------------------------------
 //
+// flxmlrpc Copyright (c) 2015 by W1HKJ, Dave Freese <iam_w1hkj@w1hkj.com>
+//    
 // XmlRpc++ Copyright (c) 2002-2008 by Chris Morley
 //
-// Copyright (C) 2014
-//              David Freese, W1HKJ
-//
 // This file is part of fldigi
 //
-// fldigi is free software; you can redistribute it and/or modify
-// it under the terms of the GNU General Public License as published by
+// flxmlrpc is free software; you can redistribute it and/or modify
+// it under the terms of the GNU Lesser General Public License as published by
 // the Free Software Foundation; either version 3 of the License, or
 // (at your option) any later version.
 //
-// fldigi is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
-//
 // You should have received a copy of the GNU General Public License
 // along with this program.  If not, see <http://www.gnu.org/licenses/>.
 // ----------------------------------------------------------------------------
 
 #include <config.h>
 
+#include <sys/types.h>
+#include <unistd.h>
+
 #include "XmlRpcClient.h"
 
 #include "XmlRpcSocket.h"
 #include "XmlRpc.h"
 
-#include "base64.h"   // For HTTP authentication encoding
+#include "XmlRpcBase64.h"   // For HTTP authentication encoding
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -41,18 +38,17 @@ using namespace std;
 
 // Static data
 const char REQUEST_BEGIN[] = 
-  "<?xml version=\"1.0\"?>\r\n"
+  "<?xml version=\"1.0\"?>\r\n";
+const char REQUEST_BEGIN_METHODNAME[] =
   "<methodCall><methodName>";
 const char REQUEST_END_METHODNAME[] = "</methodName>\r\n";
+
 const char PARAMS_TAG[] = "<params>";
 const char PARAMS_ETAG[] = "</params>";
 const char PARAM_TAG[] = "<param>";
 const char PARAM_ETAG[] =  "</param>";
 const char REQUEST_END[] = "</methodCall>\r\n";
 
-
-
-
 XmlRpcClient::XmlRpcClient(const char* host, int port, const char* uri/*=0*/)
 {
   XmlRpcUtil::log(1, "XmlRpcClient new client: host %s, port %d.", host, port);
@@ -255,12 +251,27 @@ XmlRpcClient::doConnect()
 }
 
 // Encode the request to call the specified method with the specified parameters into xml
+
+std::string XmlRpc::pname = "N/A";
+
+void 
+XmlRpc::set_pname(std::string pn)
+{
+  XmlRpc::pname = pn;
+};
+
 bool 
 XmlRpcClient::generateRequest(const char* methodName, XmlRpcValue const& params)
 {
   std::string body = REQUEST_BEGIN;
-  body += methodName;
-  body += REQUEST_END_METHODNAME;
+  if (XmlRpc::pname != "N/A") {
+    char pid[100];
+    snprintf(pid, sizeof(pid), "%s %d", XmlRpc::pname.c_str(), getpid());
+    body.append("<?clientid=\"").append(pid).append("\"?>\r\n");
+  }
+  body.append(REQUEST_BEGIN_METHODNAME);
+  body.append(methodName);
+  body.append(REQUEST_END_METHODNAME);
 
   // If params is an array, each element is a separate parameter
   if (params.valid()) {
@@ -313,14 +324,14 @@ XmlRpcClient::generateHeader(std::string const& body)
     // convert to base64
     std::vector<char> base64data;
     int iostatus = 0;
-    base64<char> encoder;
+    xmlrpc_base64<char> encoder;
     std::back_insert_iterator<std::vector<char> > ins =
       std::back_inserter(base64data);
 
     std::string authBuf = _login + ":" + _password;
 
     encoder.put(authBuf.begin(), authBuf.end(), ins, iostatus,
-                base64<>::crlf());
+                xmlrpc_base64<>::crlf());
 
     header += "Authorization: Basic ";
     std::string authEnc(base64data.begin(), base64data.end());
@@ -338,7 +349,7 @@ XmlRpcClient::generateHeader(std::string const& body)
 
   header += "Content-Type: text/xml\r\nContent-length: ";
 
-  sprintf(buff,"%"PRIuSZ"\r\n\r\n", body.size());
+  sprintf(buff,"%d\r\n\r\n", static_cast<int>(body.size()));
 
   return header + buff;
 }
